const hooks = {
    init: async (context: TinkrInitContext) => {
        console.log("Example plugin loaded", context);
    },

    preLaunch: async (context: TinkrPreLaunchContext) => {
        const { utils, wowPath, tinkrPath, gameVersion, gameRegion } = context;
        // Example of downloading a file
        const fileDownloaded = await utils.downloadFile("tinkr", "my-plugin.zip", "https://example.com/my-plugin.zip").catch((error)=> {
            console.error("Failed to download file", error);
        });

        // files are cached, so this will not download the file again if it has already been downloaded
        if (fileDownloaded) {
            // Example of unzipping a file
            await utils.unzipFile("tinkr", "my-plugin.zip", "tinkr", "my-plugin-zip").catch((error) => {
                console.error("Failed to unzip file", error);
            });
        }

        // Example of writing to the tinkr directory
        await utils.writeFile("tinkr", "my-plugin.txt", "Hello, world!").catch((error) => {
            console.error("Failed to write file", error);
        });;

        // Example of creating a directory
        await utils.createDir("tinkr", "my-plugin-dir").catch((error) => {
            console.error("Failed to create directory", error);
        });

        // Example of writing to a directory
        await utils.writeFile("tinkr", "my-plugin-dir/my-plugin.txt", "Hello, world!").catch((error) => {
            console.error("Failed to write file", error);
        });

        // Example of reading a file
        const fileContents = await utils.readFile("tinkr", "my-plugin-dir/my-plugin.txt").catch((error) => {
            console.error("Failed to read file", error);
        });
        console.log("File contents:", fileContents);
    },

    postLaunch: async (context: TinkrPostLaunchContext) => {
        console.log("postLaunch hook", context);
    },
};

export default hooks;
